@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -18,6 +18,7 @@
 
 #include "commands/help-commands.hpp"
 #include "util/i18n.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gio/gio.h>
 #include <gtkmm/messagedialog.h>
@@ -44,8 +45,10 @@ Gobby::HelpCommands::HelpCommands(Gtk::Window& parent, Header& header,
                                   const IconManager& icon_manager):
 	m_parent(parent), m_header(header), m_icon_manager(icon_manager)
 {
+#ifndef USE_GTKMM3
 	Gtk::AboutDialog::set_url_hook(sigc::ptr_fun(url_hook));
 	Gtk::AboutDialog::set_email_hook(sigc::ptr_fun(email_hook));
+#endif
 
 	header.action_help_contents->signal_activate().connect(
 		sigc::mem_fun(*this, &HelpCommands::on_contents));
@@ -97,6 +100,8 @@ void Gobby::HelpCommands::on_about()
 		std::vector<Glib::ustring> translators;
 		translators.push_back(_("British English:"));
 		translators.push_back("\tGabríel A. Pétursson <gabrielp@simnet.is>");
+		translators.push_back(_("German:"));
+		translators.push_back("\tMichael Frey <michael.frey@gmx.ch>");
 
 		Glib::ustring transl = "";
 		for(std::vector<Glib::ustring>::iterator i = translators.begin();
@@ -110,7 +115,7 @@ void Gobby::HelpCommands::on_about()
 		m_about_dialog->set_authors(authors);
 		m_about_dialog->set_translator_credits(transl);
 		m_about_dialog->set_copyright(
-			"Copyright © 2008, 2009 Armin Burgmeier");
+			"Copyright © 2008-2011 Armin Burgmeier");
 		m_about_dialog->set_license(_(
 			"This program is free software; you can redistribute "
 			"it and/or modify it under the terms of the GNU "
@@ -126,8 +131,9 @@ void Gobby::HelpCommands::on_about()
 
 			"You should have received a copy of the GNU General "
 			"Public License along with this program; if not, "
-			"write to the Free Software Foundation, Inc., 675 "
-			"Mass Ave, Cambridge, MA 02139, USA."));
+			"write to the Free Software Foundation, Inc., 51 "
+			"Franklin Street, Fifth Floor, Boston, MA  "
+                        "02110-1301, USA"));
 		m_about_dialog->set_logo_icon_name("gobby-0.5");
 		m_about_dialog->set_program_name("Gobby");
 		m_about_dialog->set_version(PACKAGE_VERSION);
