@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -18,6 +18,7 @@
 
 #include "commands/view-commands.hpp"
 #include "util/i18n.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <libinftextgtk/inf-text-gtk-buffer.h>
 
@@ -214,7 +215,7 @@ void Gobby::ViewCommands::on_chat_document_changed(SessionView* view)
 {
 	if(view != NULL)
 	{
-		if(m_chat_frame.is_visible())
+		if(GtkCompat::is_visible(m_chat_frame))
 		{
 			m_header.action_view_chat_userlist->set_sensitive(
 				true);
