@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -35,8 +35,6 @@
 #include <libinfgtk/inf-gtk-browser-model.h>
 #include <libinfgtk/inf-gtk-browser-model-sort.h>
 
-#include <gsasl.h>
-
 #include <gtkmm/window.h>
 #include <gtkmm/box.h>
 #include <gtkmm/button.h>
@@ -80,7 +78,8 @@ public:
 
 	void connect_to_host(Glib::ustring str);
 
-	void set_gsasl_context(Gsasl* gsasl, const char* mechanisms);
+	void set_sasl_context(InfSaslContext* sasl_context,
+	                      const char* mechanisms);
 
 	SignalActivate signal_activate() const { return m_signal_activate; }
 
@@ -126,8 +125,8 @@ protected:
 	StatusBar& m_status_bar;
 	Preferences& m_preferences;
 
-	Gsasl* m_gsasl;
-	std::string m_gsasl_mechanisms;
+	InfSaslContext* m_sasl_context;
+	std::string m_sasl_mechanisms;
 	InfXmppManager* m_xmpp_manager;
 #ifdef LIBINFINITY_HAVE_AVAHI
 	InfDiscoveryAvahi* m_discovery;
