@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -17,6 +17,7 @@
  */
 
 #include "core/folder.hpp"
+#include "core/textsessionuserview.hpp"
 #include "core/sessionuserview.hpp"
 #include "core/chattablabel.hpp"
 #include "core/texttablabel.hpp"
@@ -37,16 +38,16 @@ namespace
 
 		KeyMap()
 		{
-			m_keyvals[GDK_0] = 9;
-			m_keyvals[GDK_1] = 0;
-			m_keyvals[GDK_2] = 1;
-			m_keyvals[GDK_3] = 2;
-			m_keyvals[GDK_4] = 3;
-			m_keyvals[GDK_5] = 4;
-			m_keyvals[GDK_6] = 5;
-			m_keyvals[GDK_7] = 6;
-			m_keyvals[GDK_8] = 7;
-			m_keyvals[GDK_9] = 8;
+			m_keyvals[GDK_KEY_0] = 9;
+			m_keyvals[GDK_KEY_1] = 0;
+			m_keyvals[GDK_KEY_2] = 1;
+			m_keyvals[GDK_KEY_3] = 2;
+			m_keyvals[GDK_KEY_4] = 3;
+			m_keyvals[GDK_KEY_5] = 4;
+			m_keyvals[GDK_KEY_6] = 5;
+			m_keyvals[GDK_KEY_7] = 6;
+			m_keyvals[GDK_KEY_8] = 7;
+			m_keyvals[GDK_KEY_9] = 8;
 		}
 
 		unsigned int lookup(guint key) const
@@ -115,9 +116,7 @@ Gobby::Folder::~Folder()
 	// Remove all documents explicitely, so that all sessions are closed,
 	// and records finished.
 	while(get_n_pages())
-		remove_document(
-			static_cast<SessionUserView*>(
-				get_nth_page(0))->get_session_view());
+		remove_document(get_document(0));
 }
 
 // TODO: Share common code of add_text_session and add_chat_session
@@ -135,8 +134,8 @@ Gobby::Folder::add_text_session(InfTextSession* session,
 	view->show();
 	m_signal_document_added.emit(*view);
 
-	SessionUserView* userview = Gtk::manage(
-		new SessionUserView(
+	TextSessionUserView* userview = Gtk::manage(
+		new TextSessionUserView(
 			*view, true,
 			m_preferences.appearance.show_document_userlist,
 			m_preferences.appearance.document_userlist_width));
@@ -202,7 +201,10 @@ void Gobby::Folder::remove_document(SessionView& view)
 	g_object_set_data(G_OBJECT(session), "GOBBY_SESSION_RECORD", NULL);
 
 	g_object_ref(session);
-	inf_session_close(session);
+	// Session could be closed already, for example if synchronization
+	// failed.
+	if(inf_session_get_status(session) != INF_SESSION_CLOSED)
+		inf_session_close(session);
 	// This relies on the sessionuserview being the direct parent of
 	// view - maybe we should make a loop here instead which searches
 	// the folder in the widget hierarchy, to be more robust.
@@ -216,20 +218,22 @@ void Gobby::Folder::remove_document(SessionView& view)
 		set_show_tabs(false);
 }
 
+Gobby::SessionView& Gobby::Folder::get_document(unsigned int n)
+{
+	SessionUserView* child =
+		static_cast<SessionUserView*>(get_nth_page(n));
+	if(!child)
+		throw std::logic_error("Gobby::Folder::get_document: out of bounds");
+	return child->get_session_view();
+}
+
 Gobby::SessionView*
 Gobby::Folder::lookup_document(InfSession* session)
 {
-	const PageList& pagelist = pages();
-	for(PageList::iterator iter = pagelist.begin();
-	    iter != pagelist.end(); ++ iter)
-	{
-		SessionUserView* child =
-			static_cast<SessionUserView*>(iter->get_child());
-
-		if(child->get_session_view().get_session() == session)
-			return &child->get_session_view();
-	}
-
+	const unsigned int n_pages = get_n_pages();
+	for(unsigned int i = 0; i < n_pages; ++i)
+		if(get_document(i).get_session() == session)
+			return &get_document(i);
 	return NULL;
 }
 
@@ -266,11 +270,12 @@ void Gobby::Folder::on_tab_close_request(SessionView& view)
 		remove_document(view);
 }
 
-void Gobby::Folder::on_switch_page(GtkNotebookPage* page, guint page_num)
+void Gobby::Folder::on_switch_page(Gtk::Widget* page, guint page_num)
 {
-	Gtk::Notebook::on_switch_page(page, page_num);
-	SessionUserView& view =
-		*static_cast<SessionUserView*>(get_nth_page(page_num));
+	Notebook::on_switch_page(page, page_num);
+//	SessionUserView& view =
+//		*static_cast<SessionUserView*>(get_nth_page(page_num));
+	SessionUserView& view = *static_cast<SessionUserView*>(page);
 
 	m_signal_document_changed.emit(&view.get_session_view());
 }
@@ -293,8 +298,8 @@ bool Gobby::Folder::on_key_press_event(GdkEventKey* event)
 	    (GDK_CONTROL_MASK | GDK_MOD1_MASK))
 	{
 		int offset = 0;
-		if(event->keyval == GDK_Page_Up) offset = -1;
-		if(event->keyval == GDK_Page_Down) offset = 1;
+		if(event->keyval == GDK_KEY_Page_Up) offset = -1;
+		if(event->keyval == GDK_KEY_Page_Down) offset = 1;
 
 		if(offset != 0)
 		{
