@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -23,6 +23,7 @@
 #include "core/chatsessionview.hpp"
 #include "core/preferences.hpp"
 #include "util/defaultaccumulator.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gtkmm/notebook.h>
 #include <sigc++/signal.h>
@@ -32,7 +33,7 @@
 namespace Gobby
 {
 
-class Folder : public Gtk::Notebook
+class Folder : public GtkCompat::Notebook
 {
 public:
 	// TODO chat: This should be SignalSessionAdded/Removed/Changed
@@ -61,6 +62,8 @@ public:
 	                                  const Glib::ustring& hostname);
 	void remove_document(SessionView& view);
 
+	SessionView& get_document(unsigned int n);
+
 	SessionView* lookup_document(InfSession* session);
 	SessionView* get_current_document();
 	const SessionView* get_current_document() const;
@@ -87,7 +90,7 @@ public:
 	}
 
 protected:
-	virtual void on_switch_page(GtkNotebookPage* page, guint page_num);
+	virtual void on_switch_page(Gtk::Widget* page, guint page_num);
 	virtual bool on_key_press_event(GdkEventKey* event);
 
 	void on_tab_close_request(SessionView& window);
