@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -32,7 +32,12 @@ Gtk::StockID Gobby::IconManager::STOCK_USER_COLOR_INDICATOR(
 // TODO: The save-all icon does not match the save icon for toolbar
 // or menu sized items. It is not yet enabled therefore.
 Gobby::IconManager::IconManager():
-	m_icon_factory(Gtk::IconFactory::create() )
+	m_is_save_all(GtkCompat::create_icon_set()),
+	m_is_userlist(GtkCompat::create_icon_set()),
+	m_is_doclist(GtkCompat::create_icon_set()),
+	m_is_chat(GtkCompat::create_icon_set()),
+	m_is_user_color_indicator(GtkCompat::create_icon_set()),
+	m_icon_factory(Gtk::IconFactory::create())
 {
 	Gtk::IconTheme::get_default()->append_search_path(PUBLIC_ICONS_DIR);
 	Gtk::IconTheme::get_default()->append_search_path(PRIVATE_ICONS_DIR);
@@ -42,25 +47,25 @@ Gobby::IconManager::IconManager():
 
 	Gtk::IconSource userlist_source;
 	userlist_source.set_icon_name("user-list");
-	m_is_userlist.add_source(userlist_source);
+	m_is_userlist->add_source(userlist_source);
 	Gtk::StockItem userlist_item(STOCK_USERLIST, _("User list") );
 	m_icon_factory->add(STOCK_USERLIST, m_is_userlist);
 
 	Gtk::IconSource doclist_source;
 	doclist_source.set_icon_name("document-list");
-	m_is_doclist.add_source(doclist_source);
+	m_is_doclist->add_source(doclist_source);
 	Gtk::StockItem doclist_item(STOCK_DOCLIST, _("Document list") );
 	m_icon_factory->add(STOCK_DOCLIST, m_is_doclist);
 
 	Gtk::IconSource chat_source;
 	chat_source.set_icon_name("chat");
-	m_is_chat.add_source(chat_source);
+	m_is_chat->add_source(chat_source);
 	Gtk::StockItem chat_item(STOCK_CHAT, _("Chat") );
 	m_icon_factory->add(STOCK_CHAT, m_is_chat);
 
 	Gtk::IconSource user_color_indicator_source;
 	user_color_indicator_source.set_icon_name("user-color-indicator");
-	m_is_user_color_indicator.add_source(user_color_indicator_source);
+	m_is_user_color_indicator->add_source(user_color_indicator_source);
 	Gtk::StockItem user_color_indicator_item(STOCK_USER_COLOR_INDICATOR,
 	                                         _("User Color Indicator"));
 	m_icon_factory->add(STOCK_USER_COLOR_INDICATOR,
