@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,6 +24,8 @@
 #include <gtkmm/iconset.h>
 #include <gtkmm/iconfactory.h>
 
+#include "util/gtk-compat.hpp"
+
 namespace Gobby
 {
 	class IconManager
@@ -38,11 +40,11 @@ namespace Gobby
 		IconManager();
 
 	protected:
-		Gtk::IconSet m_is_save_all;
-		Gtk::IconSet m_is_userlist;
-		Gtk::IconSet m_is_doclist;
-		Gtk::IconSet m_is_chat;
-		Gtk::IconSet m_is_user_color_indicator;
+		GtkCompat::IconSet m_is_save_all;
+		GtkCompat::IconSet m_is_userlist;
+		GtkCompat::IconSet m_is_doclist;
+		GtkCompat::IconSet m_is_chat;
+		GtkCompat::IconSet m_is_user_color_indicator;
 
 		Glib::RefPtr<Gtk::IconFactory> m_icon_factory;
 	};
