@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,7 +25,15 @@ Gobby::Preferences::User::User(Config::ParentEntry& entry):
 	name(entry.get_value<Glib::ustring>("name", Glib::get_user_name())),
 	hue(entry.get_value<double>("hue", Glib::Rand().get_double())),
 	host_directory(entry.get_value<std::string>("host-directory",
-		Glib::build_filename(Glib::get_home_dir(), ".infinote")))
+		Glib::build_filename(Glib::get_home_dir(), ".infinote"))),
+	show_remote_cursors(entry.get_value<bool>(
+		"show-remote-users", true)),
+	show_remote_selections(entry.get_value<bool>(
+		"show-remote-selections", true)),
+	show_remote_current_lines(entry.get_value<bool>(
+		"show-remote-current-lines", true)),
+	show_remote_cursor_positions(entry.get_value<bool>(
+		"show-remote-cursor-positions", true))
 {
 }
 
@@ -34,6 +42,12 @@ void Gobby::Preferences::User::serialize(Config::ParentEntry& entry) const
 	entry.set_value("name", name);
 	entry.set_value("hue", hue);
 	entry.set_value("host-directory", host_directory);
+	
+	entry.set_value("show-remote-cursors", show_remote_cursors);
+	entry.set_value("show-remote-selections", show_remote_selections);
+	entry.set_value("show-remote-current-lines", show_remote_current_lines);
+	entry.set_value("show-remote-cursor-positions",
+	                show_remote_cursor_positions);
 }
 
 Gobby::Preferences::Editor::Editor(Config::ParentEntry& entry):
@@ -89,11 +103,11 @@ Gobby::Preferences::Appearance::Appearance(Config::ParentEntry& entry):
 		"toolbar-style", static_cast<int>(Gtk::TOOLBAR_BOTH)))),
 	font(Pango::FontDescription(entry.get_value<Glib::ustring>(
 		"font", "Monospace 10"))),
+	scheme_id(entry.get_value<Glib::ustring>("scheme-id", "classic")),
 	document_userlist_width(entry.get_value<unsigned int>(
 		"document-userlist-width", 150)),
 	chat_userlist_width(entry.get_value<unsigned int>(
 		"chat-userlist-width", 150)),
-	scheme_id(entry.get_value<Glib::ustring>("scheme-id", "classic")),
 
 	show_toolbar(entry.get_value<bool>("show-toolbar", true)),
 	show_statusbar(entry.get_value<bool>("show-statusbar", true)),
