@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -105,6 +105,11 @@ public:
 		Option<Glib::ustring> name;
 		Option<double> hue;
 		Option<std::string> host_directory;
+
+		Option<bool> show_remote_cursors;
+		Option<bool> show_remote_selections;
+		Option<bool> show_remote_current_lines;
+		Option<bool> show_remote_cursor_positions;
 	};
 
 	class Editor
