@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -18,6 +18,7 @@
 
 #include "core/tablabel.hpp"
 #include "core/folder.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gtkmm/stock.h>
 
@@ -27,7 +28,7 @@ Gobby::TabLabel::TabLabel(Folder& folder, SessionView& view,
 	m_title(view.get_title()), m_changed(false),
 	m_active_icon(active_icon)
 {
-	m_title.set_alignment(Gtk::ALIGN_LEFT);
+	m_title.set_alignment(GtkCompat::ALIGN_LEFT);
 
 	update_icon();
 	update_color();
@@ -146,28 +147,40 @@ void Gobby::TabLabel::update_color()
 	if(m_changed)
 	{
 		// Document has changed: awareness -> red
+#ifdef USE_GTKMM3
+		m_title.override_color(Gdk::RGBA("#c00000"));
+#else
 		m_title.modify_fg(Gtk::STATE_NORMAL, Gdk::Color("#c00000"));
 		m_title.modify_fg(Gtk::STATE_ACTIVE, Gdk::Color("#c00000"));
+#endif
 	}
 	else if(inf_session_get_subscription_group(session) == NULL ||
 	        inf_session_get_status(session) != INF_SESSION_RUNNING)
 	{
 		// Document disconnected or not yet running
 		// (most probably synchronizing): not (yet) available -> grey
+#ifdef USE_GTKMM3
+		m_title.override_color(Gdk::RGBA("#606060"));
+#else
 		m_title.modify_fg(Gtk::STATE_NORMAL, Gdk::Color("#606060"));
 		m_title.modify_fg(Gtk::STATE_ACTIVE, Gdk::Color("#606060"));
+#endif
 	}
 	else
 	{
+		// Otherwise default
+#ifdef USE_GTKMM3
+		m_title.unset_color();
+#else
 		Glib::RefPtr<Gtk::Style> default_style =
 			Gtk::Widget::get_default_style();
 
-		// Otherwise default
 		m_title.modify_fg(
 			Gtk::STATE_ACTIVE,
 			default_style->get_fg(Gtk::STATE_ACTIVE));
 		m_title.modify_fg(
 			Gtk::STATE_NORMAL,
 			default_style->get_fg(Gtk::STATE_NORMAL));
+#endif
 	}
 }
