@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,6 +25,8 @@
 
 #include <libinftextgtk/inf-text-gtk-buffer.h>
 
+// TODO: Put all the preferences handling into an extra class
+
 namespace
 {
 	GtkWrapMode wrap_mode_from_preferences(const Gobby::Preferences& pref)
@@ -126,9 +128,16 @@ Gobby::TextSessionView::TextSessionView(InfTextSession* session,
 	m_view(GTK_SOURCE_VIEW(gtk_source_view_new()))
 {
 	InfBuffer* buffer = inf_session_get_buffer(INF_SESSION(session));
+	InfUserTable* user_table =
+		inf_session_get_user_table(INF_SESSION(session));
 	m_buffer = GTK_SOURCE_BUFFER(inf_text_gtk_buffer_get_text_buffer(
 		INF_TEXT_GTK_BUFFER(buffer)));
 
+	m_infview = inf_text_gtk_view_new(
+		inf_adopted_session_get_io(INF_ADOPTED_SESSION(session)),
+		GTK_TEXT_VIEW(m_view),
+		user_table);
+
 	g_signal_connect_after(
 		G_OBJECT(m_view),
 		"style-set",
@@ -157,6 +166,18 @@ Gobby::TextSessionView::TextSessionView(InfTextSession* session,
 	m_preferences.user.hue.signal_changed().connect(
 		sigc::mem_fun(
 			*this, &TextSessionView::on_user_color_changed));
+	m_preferences.user.show_remote_cursors.signal_changed().connect(
+		sigc::mem_fun(
+			*this, &TextSessionView::on_show_remote_cursors_changed));
+	m_preferences.user.show_remote_selections.signal_changed().connect(
+		sigc::mem_fun(
+			*this, &TextSessionView::on_show_remote_selections_changed));
+	m_preferences.user.show_remote_current_lines.signal_changed().connect(
+		sigc::mem_fun(
+			*this, &TextSessionView::on_show_remote_current_lines_changed));
+	m_preferences.user.show_remote_cursor_positions.signal_changed().connect(
+		sigc::mem_fun(
+			*this, &TextSessionView::on_show_remote_cursor_positions_changed));
 	m_preferences.editor.tab_width.signal_changed().connect(
 		sigc::mem_fun(
 			*this, &TextSessionView::on_tab_width_changed));
@@ -198,6 +219,20 @@ Gobby::TextSessionView::TextSessionView(InfTextSession* session,
 		sigc::mem_fun(*this, &TextSessionView::on_font_changed));
 	m_preferences.appearance.scheme_id.signal_changed().connect(
 		sigc::mem_fun(*this, &TextSessionView::on_scheme_changed));
+
+	inf_text_gtk_view_set_show_remote_cursors(
+		m_infview,
+		m_preferences.user.show_remote_cursors
+	);
+	inf_text_gtk_view_set_show_remote_selections(
+		m_infview,
+		m_preferences.user.show_remote_selections
+	);
+	inf_text_gtk_view_set_show_remote_current_lines(
+		m_infview,
+		m_preferences.user.show_remote_current_lines
+	);
+
 	gtk_source_view_set_tab_width(m_view, m_preferences.editor.tab_width);
 	gtk_source_view_set_insert_spaces_instead_of_tabs(
 		m_view, m_preferences.editor.tab_spaces);
@@ -234,9 +269,26 @@ Gobby::TextSessionView::TextSessionView(InfTextSession* session,
 	gtk_container_add(GTK_CONTAINER(scroll->gobj()), GTK_WIDGET(m_view));
 	scroll->show();
 
+	m_infviewport = inf_text_gtk_viewport_new(scroll->gobj(), user_table);
+	inf_text_gtk_viewport_set_show_user_markers(
+		m_infviewport,
+		m_preferences.user.show_remote_cursor_positions
+	);
+
 	pack_start(*scroll, Gtk::PACK_EXPAND_WIDGET);
-	
-	gtk_source_buffer_set_style_scheme(m_buffer, gtk_source_style_scheme_manager_get_scheme(gtk_source_style_scheme_manager_get_default(), static_cast<Glib::ustring>(preferences.appearance.scheme_id).c_str()));
+
+	gtk_source_buffer_set_style_scheme(
+		m_buffer,
+		gtk_source_style_scheme_manager_get_scheme(
+			gtk_source_style_scheme_manager_get_default(),
+			static_cast<Glib::ustring>(
+				preferences.appearance.scheme_id).c_str()));
+}
+
+Gobby::TextSessionView::~TextSessionView()
+{
+	g_object_unref(m_infview);
+	g_object_unref(m_infviewport);
 }
 
 void Gobby::TextSessionView::get_cursor_position(unsigned int& row,
@@ -252,7 +304,7 @@ void Gobby::TextSessionView::get_cursor_position(unsigned int& row,
 	row = gtk_text_iter_get_line(&iter);
 	col = 0;
 
-	unsigned int chars = gtk_text_iter_get_line_offset(&iter);
+	int chars = gtk_text_iter_get_line_offset(&iter);
 	unsigned int tabs = m_preferences.editor.tab_width;
 
 	// Tab characters expand to more than one column
@@ -322,6 +374,8 @@ void Gobby::TextSessionView::set_active_user(InfTextUser* user)
 		INF_TEXT_GTK_BUFFER(
 			inf_session_get_buffer(INF_SESSION(m_session))),
 		user);
+	inf_text_gtk_view_set_active_user(m_infview, user);
+	inf_text_gtk_viewport_set_active_user(m_infviewport, user);
 
 	// TODO: Make sure the active user has the color specified in the
 	// preferences, and set color if not.
@@ -369,6 +423,39 @@ void Gobby::TextSessionView::on_user_color_changed()
 	}
 }
 
+
+void Gobby::TextSessionView::on_show_remote_cursors_changed()
+{
+	inf_text_gtk_view_set_show_remote_cursors(
+		m_infview,
+		m_preferences.user.show_remote_cursors
+	);
+}
+
+void Gobby::TextSessionView::on_show_remote_selections_changed()
+{
+	inf_text_gtk_view_set_show_remote_selections(
+		m_infview,
+		m_preferences.user.show_remote_selections
+	);
+}
+
+void Gobby::TextSessionView::on_show_remote_current_lines_changed()
+{
+	inf_text_gtk_view_set_show_remote_current_lines(
+		m_infview,
+		m_preferences.user.show_remote_current_lines
+	);
+}
+
+void Gobby::TextSessionView::on_show_remote_cursor_positions_changed()
+{
+	inf_text_gtk_viewport_set_show_user_markers(
+		m_infviewport,
+		m_preferences.user.show_remote_cursor_positions
+	);
+}
+
 void Gobby::TextSessionView::on_tab_width_changed()
 {
 	gtk_source_view_set_tab_width(m_view, m_preferences.editor.tab_width);
@@ -447,7 +534,12 @@ void Gobby::TextSessionView::on_font_changed()
 
 void Gobby::TextSessionView::on_scheme_changed()
 {
-	gtk_source_buffer_set_style_scheme(m_buffer, gtk_source_style_scheme_manager_get_scheme(gtk_source_style_scheme_manager_get_default(), static_cast<Glib::ustring>(m_preferences.appearance.scheme_id).c_str()));
+	gtk_source_buffer_set_style_scheme(
+		m_buffer,
+		gtk_source_style_scheme_manager_get_scheme(
+			gtk_source_style_scheme_manager_get_default(),
+			static_cast<Glib::ustring>(
+				m_preferences.appearance.scheme_id).c_str()));
 }
 
 bool Gobby::TextSessionView::
