@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,6 +21,7 @@
 
 #include "util/i18n.hpp"
 #include "util/color.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/stock.h>
@@ -39,16 +40,20 @@ namespace
 	Glib::RefPtr<Gdk::Pixbuf> generate_user_color_pixbuf(Gtk::Widget& w,
 	                                                     gdouble hue)
 	{
-		Glib::RefPtr<Gdk::Pixbuf> pixbuf = w.render_icon(
-			Gobby::IconManager::STOCK_USER_COLOR_INDICATOR,
-			Gtk::ICON_SIZE_MENU);
+		Gtk::StockID id =
+			Gobby::IconManager::STOCK_USER_COLOR_INDICATOR;
+
+		Glib::RefPtr<Gdk::Pixbuf> pixbuf =
+			Gobby::GtkCompat::render_icon(
+				w, id,
+				Gtk::ICON_SIZE_MENU);
 
 		// pixbuf is shared, though we want to mess with it here
 		pixbuf = pixbuf->copy();
 
-		for(unsigned int y = 0; y < pixbuf->get_height(); ++y)
+		for(int y = 0; y < pixbuf->get_height(); ++y)
 		{
-			for(unsigned int x = 0; x < pixbuf->get_width(); ++x)
+			for(int x = 0; x < pixbuf->get_width(); ++x)
 			{
 				guint8* pixels = pixbuf->get_pixels();
 				guint8* pixel =
@@ -117,6 +122,9 @@ Gobby::UserList::UserList(InfUserTable* table):
 		*name_renderer,
 		sigc::mem_fun(*this, &UserList::name_cell_data_func));
 
+	m_view.signal_row_activated().connect(
+		sigc::mem_fun(*this, &UserList::on_row_activated));
+
 	column->set_spacing(6);
 	m_view.append_column(*column);
 	m_view.get_selection()->set_mode(Gtk::SELECTION_NONE);
@@ -327,6 +335,22 @@ void Gobby::UserList::on_notify_status(InfUser* user)
 	(*iter)[m_columns.user] = user;
 }
 
+void Gobby::UserList::on_row_activated(const Gtk::TreePath& path,
+                                       Gtk::TreeViewColumn* column)
+{
+	Gtk::TreePath parent_path;
+	if(m_filter_model)
+		parent_path = m_filter_model->convert_path_to_child_path(path);
+	else
+		parent_path = path;
+
+	const Gtk::TreeIter& iter = m_store->get_iter(path);
+	InfUser* user = (*iter)[m_columns.user];
+
+	if(inf_user_get_status(user) != INF_USER_UNAVAILABLE)
+		m_signal_user_activated.emit(user);
+}
+
 Gtk::TreeIter Gobby::UserList::find_user_iter(InfUser* user)
 {
 	const Gtk::TreeModel::Children& children = m_store->children();
