@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -18,6 +18,7 @@
 
 #include "dialogs/goto-dialog.hpp"
 #include "util/i18n.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/textbuffer.h>
@@ -27,7 +28,7 @@ Gobby::GotoDialog::GotoDialog(Gtk::Window& parent, Folder& folder):
 	Gtk::Dialog(_("Go to line"), parent),
 	m_folder(folder),
 	m_table(1, 2),
-	m_label_line(_("Line _number:"), Gtk::ALIGN_LEFT,
+	m_label_line(_("Line _number:"), GtkCompat::ALIGN_LEFT,
 	             Gtk::ALIGN_CENTER, true),
 	m_current_view(NULL)
 {
