@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -19,6 +19,7 @@
 #include "dialogs/preferences-dialog.hpp"
 #include "util/color.hpp"
 #include "util/i18n.hpp"
+#include "util/gtk-compat.hpp"
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/scrolledwindow.h>
@@ -231,14 +232,21 @@ Gobby::PreferencesDialog::User::User(Gtk::Window& parent,
                                      Preferences& preferences):
 	m_group_settings(_("Settings")),
 	m_group_paths(_("Paths")),
+	m_group_remote(_("Remote Users")),
 	m_box_user_name(false, 6),
-	m_lbl_user_name(_("User name:"), Gtk::ALIGN_LEFT),
+	m_lbl_user_name(_("User name:"), GtkCompat::ALIGN_LEFT),
 	m_box_user_color(false, 6),
-	m_lbl_user_color(_("User color:"), Gtk::ALIGN_LEFT),
+	m_lbl_user_color(_("User color:"), GtkCompat::ALIGN_LEFT),
 	m_btn_user_color(_("Choose a new user color"), parent),
 	m_box_path_host_directory(false, 6),
-	m_btn_path_host_directory(Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER),
 	m_lbl_path_host_directory(_("Host directory:")),
+	m_btn_path_host_directory(Gtk::FILE_CHOOSER_ACTION_SELECT_FOLDER),
+	m_btn_remote_show_cursors(_("Show cursors of remote users")),
+	m_btn_remote_show_selections(_("Show selections of remote users")),
+	m_btn_remote_show_current_lines(
+		_("Highlight current line of remote users")),
+	m_btn_remote_show_cursor_positions(
+		_("Indicate remote users' cursor position in the scrollbar")),
 	m_size_group(Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL))
 {
 	m_lbl_user_name.show();
@@ -292,8 +300,39 @@ Gobby::PreferencesDialog::User::User(Gtk::Window& parent,
 	// Disable until we support self-hosting:
 	// m_group_paths.show();
 
+	m_btn_remote_show_cursors.set_active(
+		preferences.user.show_remote_cursors);
+	m_btn_remote_show_cursors.show();
+	connect_option(m_btn_remote_show_cursors,
+	               preferences.user.show_remote_cursors);
+
+	m_btn_remote_show_selections.set_active(
+		preferences.user.show_remote_selections);
+	m_btn_remote_show_selections.show();
+	connect_option(m_btn_remote_show_selections,
+	               preferences.user.show_remote_selections);
+
+	m_btn_remote_show_current_lines.set_active(
+		preferences.user.show_remote_current_lines);
+	m_btn_remote_show_current_lines.show();
+	connect_option(m_btn_remote_show_current_lines,
+	               preferences.user.show_remote_current_lines);
+
+	m_btn_remote_show_cursor_positions.set_active(
+		preferences.user.show_remote_cursor_positions);
+	m_btn_remote_show_cursor_positions.show();
+	connect_option(m_btn_remote_show_cursor_positions,
+	               preferences.user.show_remote_cursor_positions);
+
+	m_group_remote.add(m_btn_remote_show_cursors);
+	m_group_remote.add(m_btn_remote_show_selections);
+	m_group_remote.add(m_btn_remote_show_current_lines);
+	m_group_remote.add(m_btn_remote_show_cursor_positions);
+	m_group_remote.show();
+
 	add(m_group_settings, false);
 	add(m_group_paths, false);
+	add(m_group_remote, false);
 }
 
 Gobby::PreferencesDialog::Editor::Editor(Preferences& preferences):
@@ -301,7 +340,7 @@ Gobby::PreferencesDialog::Editor::Editor(Preferences& preferences):
 	m_group_indentation(_("Indentation")),
 	m_group_homeend(_("Home/End Behavior")),
 	m_group_saving(_("File Saving")),
-	m_lbl_tab_width(_("_Tab width:"), Gtk::ALIGN_RIGHT,
+	m_lbl_tab_width(_("_Tab width:"), GtkCompat::ALIGN_RIGHT,
 	                Gtk::ALIGN_CENTER, true),
 	m_btn_tab_spaces(_("Insert _spaces instead of tabs"), true),
 	m_btn_indentation_auto(_("Enable automatic _indentation"), true),
@@ -602,7 +641,11 @@ Gobby::PreferencesDialog::Appearance::Appearance(Preferences& preferences):
 			sigc::mem_fun(*this, &Appearance::on_scheme_changed),
 			sigc::ref(preferences)));
 
-	m_list->set_sort_column_id(m_columns.name, Gtk::SORT_ASCENDING); // This should do it
+#ifdef USE_GTKMM3
+	m_list->set_sort_column(m_columns.name, Gtk::SORT_ASCENDING);
+#else
+	m_list->set_sort_column_id(m_columns.name, Gtk::SORT_ASCENDING);
+#endif
 
 	add(m_group_toolbar, false);
 	add(m_group_font, false);
