@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -86,7 +86,7 @@ namespace
 	                            const std::vector<Glib::ustring>& uris)
 	{
 		std::vector<const gchar*> uri_cstrs(uris.size() + 1);
-		for(int i = 0; i < uris.size(); ++i)
+		for(unsigned int i = 0; i < uris.size(); ++i)
 			uri_cstrs[i] = uris[i].c_str();
 
 		UniqueMessageData* message = unique_message_data_new();
@@ -147,7 +147,7 @@ namespace
 		const std::vector<Glib::ustring>& hostnames)
 	{
 		std::vector<Glib::ustring> uris(hostnames);
-		for(int i = 0; i < uris.size(); ++i)
+		for(unsigned int i = 0; i < uris.size(); ++i)
 		{
 			uris[i].insert(0, "infinote://");
 		}
