@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ Gobby::OperationDelete::OperationDelete(Operations& operations,
 		G_CALLBACK(on_request_finished_static), this);
 
 	m_message_handle = get_status_bar().add_info_message(
-		Glib::ustring::compose(_("Removing node %1..."), m_name));
+		Glib::ustring::compose(_("Removing node \"%1\"..."), m_name));
 }
 
 Gobby::OperationDelete::~OperationDelete()
@@ -54,7 +54,8 @@ Gobby::OperationDelete::~OperationDelete()
 void Gobby::OperationDelete::on_request_failed(const GError* error)
 {
 	get_status_bar().add_error_message(
-		Glib::ustring::compose(_("Failed to delete node %1"), m_name),
+		Glib::ustring::compose(_("Failed to delete node \"%1\""),
+		                       m_name),
 		error->message);
 
 	fail();
