@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -53,8 +53,8 @@ Gobby::OperationNew::OperationNew(Operations& operations,
 
 	m_message_handle = get_status_bar().add_info_message(
 		Glib::ustring::compose(
-			directory ? _("Creating directory %1...")
-			          : _("Creating document %1..."), name));
+			directory ? _("Creating directory \"%1\"...")
+			          : _("Creating document \"%1\"..."), name));
 }
 
 Gobby::OperationNew::~OperationNew()
@@ -70,8 +70,8 @@ void Gobby::OperationNew::on_request_failed(const GError* error)
 {
 	get_status_bar().add_error_message(
 		Glib::ustring::compose(
-			m_directory ? _("Failed to create directory %1")
-			            : _("Failed to create document %1"),
+			m_directory ? _("Failed to create directory \"%1\"")
+			            : _("Failed to create document \"%1\""),
 			m_name),
 		error->message);
 
