@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -86,7 +86,7 @@ Gobby::OperationOpen::OperationOpen(Operations& operations,
 
 		m_message_handle = get_status_bar().add_info_message(
 			Glib::ustring::compose(
-				_("Opening document %1..."), uri));
+				_("Opening document \"%1\"..."), uri));
 
 		m_parent.signal_node_removed().connect(
 			sigc::mem_fun(
