@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -30,10 +30,10 @@ Gobby::OperationSave::OperationSave(Operations& operations,
 				    DocumentInfoStorage::EolStyle eol_style):
 	Operation(operations), m_view(&view),
 	m_start_time(std::time(NULL)), m_current_line_index(0),
-	m_iconv(encoding.c_str(), "UTF-8"), m_encoding(encoding),
-	m_eol_style(eol_style),
-	m_storage_key(view.get_info_storage_key()), m_buffer_size(0),
-	m_buffer_index(0)
+	m_encoding(encoding), m_eol_style(eol_style),
+	m_storage_key(view.get_info_storage_key()),
+	m_iconv(encoding.c_str(), "UTF-8"),
+	m_buffer_size(0), m_buffer_index(0)
 {
 	// Load content so that the session can go on while saving
 	GtkTextBuffer* buffer = GTK_TEXT_BUFFER(view.get_text_buffer());
@@ -70,7 +70,8 @@ Gobby::OperationSave::OperationSave(Operations& operations,
 	                                   &OperationSave::on_file_replace));
 
 	m_message_handle = get_status_bar().add_info_message(
-		Glib::ustring::compose(_("Saving document %1 to %2..."),
+		Glib::ustring::compose(
+			_("Saving document \"%1\" to \"%2\"..."),
 			view.get_title(), uri));
 
 	folder.signal_document_removed().connect(
@@ -284,7 +285,7 @@ void Gobby::OperationSave::on_stream_write(
 void Gobby::OperationSave::error(const Glib::ustring& message)
 {
 	get_status_bar().add_error_message(
-		Glib::ustring::compose(_("Failed to save document %1"),
+		Glib::ustring::compose(_("Failed to save document \"%1\""),
 		                         m_file->get_uri()),
 		message);
 
